==> ldap-account-manager_8.3.orig.tar.bz2: ldap-account-manager-8.3/templates/lib/extra/ckeditor/plugins/table/lang/bg.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'bg', {
	border: 'Размер на рамката',
	caption: 'Заглавие',
	cell: {
		menu: 'Клетка',
		insertBefore: 'Вмъкване на клетка преди',
		insertAfter: 'Вмъкване на клетка след',
		deleteCell: 'Изтриване на клетки',
		merge: 'Сливане на клетки',
		mergeRight: 'Сливане надясно',
		mergeDown: 'Сливане надолу',
		splitHorizontal: 'Разделяне клетката хоризонтално',
		splitVertical: 'Разделяне клетката вертикално',
		title: 'Настройки на клетката',
		cellType: 'Тип на клетката',
		rowSpan: 'Редове обединени',
		colSpan: 'Колони обединени',
		wordWrap: 'Авто. пренос',
		hAlign: 'Хоризонтално подравняване',
		vAlign: 'Вертикално подравняване',
		alignBaseline: 'Базова линия',
		bgColor: 'Фон',
		borderColor: 'Цвят на рамката',
		data: 'Данни',
		header: 'Заглавие',
		yes: 'Да',
		no: 'Не',
		invalidWidth: 'Ширината на клетката трябва да е число.',
		invalidHeight: 'Височината на клетката трябва да е число.',
		invalidRowSpan: 'Редове обединени трябва да е цяло число.',
		invalidColSpan: 'Колони обединени трябва да е цяло число.',
		chooseColor: 'Изберете'
	},
	cellPad: 'Отделяне на клетките',
	cellSpace: 'Разстояние между клетките',
	column: {
		menu: 'Колона',
		insertBefore: 'Вмъкване на колона преди',
		insertAfter: 'Вмъкване на колона след',
		deleteColumn: 'Изтриване на колони'
	},
	columns: 'Колони',
	deleteTable: 'Изтриване на таблица',
	headers: 'Заглавия',
	headersBoth: 'И двете',
	headersColumn: 'Първа колона',
	headersNone: 'Няма',
	headersRow: 'Първи ред',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Размерът на рамката трябва да е число.',
	invalidCellPadding: 'Отстоянието на клетките трябва да е положително число.',
	invalidCellSpacing: 'Интервалът в клетките трябва да е положително число.',
	invalidCols: 'Броят колони трябва да е по-голям от 0.',
	invalidHeight: 'Височината на таблицата трябва да е число.',
	invalidRows: 'Броят редове трябва да е по-голям от 0.',
	invalidWidth: 'Ширината на таблицата трябва да е число.',
	menu: 'Настройки на таблицата',
	row: {
		menu: 'Ред',
		insertBefore: 'Вмъкване на ред преди',
		insertAfter: 'Вмъкване на ред след',
		deleteRow: 'Изтриване на редове'
	},
	rows: 'Редове',
	summary: 'Обща информация',
	title: 'Настройки на таблицата',
	toolbar: 'Таблица',
	widthPc: 'процент',
	widthPx: 'пиксела',
	widthUnit: 'единица за ширина'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/bg.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'bg', {
	border: 'Размер на рамката',
	caption: 'Заглавие',
	cell: {
		menu: 'Клетка',
		insertBefore: 'Вмъкване на клетка преди',
		insertAfter: 'Вмъкване на клетка след',
		deleteCell: 'Изтриване на клетки',
		merge: 'Сливане на клетки',
		mergeRight: 'Сливане надясно',
		mergeDown: 'Сливане надолу',
		splitHorizontal: 'Разделяне клетката хоризонтално',
		splitVertical: 'Разделяне клетката вертикално',
		title: 'Настройки на клетката',
		cellType: 'Тип на клетката',
		rowSpan: 'Редове обединени',
		colSpan: 'Колони обединени',
		wordWrap: 'Авто. пренос',
		hAlign: 'Хоризонтално подравняване',
		vAlign: 'Вертикално подравняване',
		alignBaseline: 'Базова линия',
		bgColor: 'Фон',
		borderColor: 'Цвят на рамката',
		data: 'Данни',
		header: 'Заглавие',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Да',
		no: 'Не',
		invalidWidth: 'Ширината на клетката трябва да е число.',
		invalidHeight: 'Височината на клетката трябва да е число.',
		invalidRowSpan: 'Редове обединени трябва да е цяло число.',
		invalidColSpan: 'Колони обединени трябва да е цяло число.',
		chooseColor: 'Изберете'
	},
	cellPad: 'Отделяне на клетките',
	cellSpace: 'Разстояние между клетките',
	column: {
		menu: 'Колона',
		insertBefore: 'Вмъкване на колона преди',
		insertAfter: 'Вмъкване на колона след',
		deleteColumn: 'Изтриване на колони'
	},
	columns: 'Колони',
	deleteTable: 'Изтриване на таблица',
	headers: 'Заглавия',
	headersBoth: 'И двете',
	headersColumn: 'Първа колона',
	headersNone: 'Няма',
	headersRow: 'Първи ред',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Размерът на рамката трябва да е число.',
	invalidCellPadding: 'Отстоянието на клетките трябва да е положително число.',
	invalidCellSpacing: 'Интервалът в клетките трябва да е положително число.',
	invalidCols: 'Броят колони трябва да е по-голям от 0.',
	invalidHeight: 'Височината на таблицата трябва да е число.',
	invalidRows: 'Броят редове трябва да е по-голям от 0.',
	invalidWidth: 'Ширината на таблицата трябва да е число.',
	menu: 'Настройки на таблицата',
	row: {
		menu: 'Ред',
		insertBefore: 'Вмъкване на ред преди',
		insertAfter: 'Вмъкване на ред след',
		deleteRow: 'Изтриване на редове'
	},
	rows: 'Редове',
	summary: 'Обща информация',
	title: 'Настройки на таблицата',
	toolbar: 'Таблица',
	widthPc: 'процент',
	widthPx: 'пиксела',
	widthUnit: 'единица за ширина'
} );
